@@ -1,4 +1,4 @@
-from .color import print_colored, colors
+from modules.color import print_colored, colors
 
 #https://patorjk.com/software/taag/
 def print_banner():
