@@ -1,9 +1,9 @@
-from .color import print_colored, colors, bcolors
-from .nvdlib.nvdlib import searchCPE, searchCVE, getCVE
+from modules.color import print_colored, colors, bcolors
+from modules.nvdlib.nvdlib import searchCPE, searchCVE, getCVE
 from textwrap import wrap
 from os import get_terminal_size
 from requests.exceptions import JSONDecodeError
-from .outfile import output
+from modules.outfile import output
 
 #generate keywords to search for from the information gathered from the target
 def GenerateKeywords(HostArray):
